/*
 * NAME
 *   ArticleIndex.c
 * DESCRIPTION
 *   Functions for access to the article index files.
 * COPYRIGHT
 *   Skim - Off-line news reading package optimized for slow lines.
 *   Copyright (C) 1996  Rene W.J. Pijlman
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * VERSION
 *   Skim version 0.8.4.
 */

#include <unistd.h>
#include <string.h>
#include <assert.h>

#include "VarBuf.h"
#include "Skim.h"
#include "StandardIO.h"
#include "Article.h"

FILE_ID("$Header: /home/rene/sys/CVS_MasterSourceRepository/skim/ArticleIndex.c,v 1.5 1996/02/16 23:10:42 rene Exp $" );


void AddArticleToIndex(
    VarBuf ArticleFileName,
    VarBuf ArticleNumber,
    StandardIO Index )
{
    VarBuf ArticleToBeIndexedVB = VBCreate();
    VarBuf HeaderContent = NULL;
    StandardIO ArticleFile = SIOCreate();
    Article ArticleToBeIndexed = ArticleCreate();

    assert( SIOIsOpenForWrite( Index ) );

    /*
     * Open the article file, read it in a VarBuf, parse the VarBuf and
     * fill an Article object.
     */
    SIOFileOpen( ArticleFile, VBAsString(ArticleFileName), OpenModeRead );
    VBReadFile( ArticleToBeIndexedVB, ArticleFile );
    ArticleSetVB( ArticleToBeIndexed, ArticleToBeIndexedVB );

    if ( ArticleIsOKAndComplete( ArticleToBeIndexed ) )
    {
        HeaderContent = ArticleGetHeaderLineValue( ArticleToBeIndexed, 
	                                           HL_SUBJECT );
	assert( HeaderContent != NULL );

	SIOPrintf( Index, "%V %V\n", ArticleNumber, HeaderContent );
    }
    else
    {
	SIOPrintf( StandardError,
	                   "Invalid article ignored:\n%V",
			   ArticleGetErrorMessages( ArticleToBeIndexed ) );
    }

    VBDestroy( HeaderContent );
    VBDestroy( ArticleToBeIndexedVB );
    SIODestroy( ArticleFile );
    ArticleDestroy( ArticleToBeIndexed );
}
