/*
 * NAME
 *   ArticleNumber.c
 * DESCRIPTION
 *   Functions to access an ArticleNumber file.
 * COPYRIGHT
 *   Skim - Off-line news reading package optimized for slow lines.
 *   Copyright (C) 1996  Rene W.J. Pijlman
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * VERSION
 *   Skim version 0.8.4.
 */

#include <stdio.h>
#include <assert.h>

#include "ArticleNumber.h"
#include "VarBuf.h"
#include "SkimUtils.h"
#include "StandardIO.h"


static void ConstructFullPathOfArticleNumberFile (
    VarBuf FullPath,
    const char * Newsgroup )
{
    assert( Newsgroup != NULL && strlen(Newsgroup) > 0 );

    VBPrintf( FullPath, "%s/CurrentArticleNumber/%s", SkimDirectory(), 
              Newsgroup );
}


void SetCurrentArticleNumber(
    char * Newsgroup,
    ArticleNumber CurrentArticleNumber )
{
    StandardIO ArticleNumberFile = SIOCreate();
    VarBuf FileName = VBCreate();

    assert( Newsgroup != NULL && strlen(Newsgroup) > 0 );

    ConstructFullPathOfArticleNumberFile ( FileName, Newsgroup );

    SIOFileOpenVB( ArticleNumberFile, FileName, OpenModeWriteDiscardOld );

    SIOPrintf( ArticleNumberFile, "%lu\n", CurrentArticleNumber );

    VBDestroy( FileName );
    SIODestroy( ArticleNumberFile );
}


ArticleNumber GetCurrentArticleNumber(
    char * Newsgroup )
{
    ArticleNumber CurrentArticleNumber;
    StandardIO ArticleNumberFile = SIOCreate();
    VarBuf FileName = VBCreate();
    VarBuf CurrentArticleNumberInVB = VBCreate();

    assert( Newsgroup != NULL && strlen(Newsgroup) > 0 );

    ConstructFullPathOfArticleNumberFile ( FileName, Newsgroup );

    SIOFileOpenVB( ArticleNumberFile, FileName, OpenModeReadIgnore );

    /*
     * This sets the initial value of the article number, and repairs the
     * current article number file when it is corrupt.
     */
    if ( !SIOIsOpenForRead( ArticleNumberFile ) ||
         !VBReadLine( CurrentArticleNumberInVB, ArticleNumberFile,
                      WITHOUT_NEWLINE ) ||
	 sscanf( VBAsString( CurrentArticleNumberInVB ),
	             "%lu", &CurrentArticleNumber ) != 1 )
    {
        CurrentArticleNumber = 1;
    }

    SIODestroy( ArticleNumberFile );

    VBDestroy( FileName );
    VBDestroy( CurrentArticleNumberInVB );

    return CurrentArticleNumber;
}
