/*
 * NAME
 *   ArticleP.h
 * DESCRIPTION
 *   Private include file of the Article class and of its component classes.
 * COPYRIGHT
 *   Skim - Off-line news reading package optimized for slow lines.
 *   Copyright (C) 1996  Rene W.J. Pijlman
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 * 
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 * 
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * VERSION
 *   Skim version 0.8.4.
 */

/*
 * The header lines of an article are represented as a set of name value 
 * pairs.
 *
 * The "Lines" header line is an exception. The number of lines in the article
 * is computed from the body of the article. The "Lines" header line in an
 * incoming or stored article is ignored.
 */
struct _HeaderLine {
    VarBuf Name;
    VarBuf Value;
};

struct _Header {
    Set HeaderLines;        /* Set of (struct _HeaderLine *). */

    VarBuf ErrorMessages;
};

struct _Body {
    /*
     * The content of the article, in UNIX text file format ('\n' terminated
     * lines).
     */
    VarBuf Text;

    VarBuf ErrorMessages;
};

struct _Article {
    Header ArticleHeader;
    Body ArticleBody;

    VarBuf ErrorMessages;
};

#define BUFFER_SIZE_FOR_DATE 128
