/*
 * NAME
 *   Set.c
 * DESCRIPTION
 * COPYRIGHT
 *   Copyright (C) 1996  Rene W.J. Pijlman
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * VERSION
 *   $Header: /home/rene/sys/CVS_MasterSourceRepository/skim/Set.c,v 1.9 1996/02/18 11:40:22 rene Exp $
 *   Distributed with Skim version 0.8.4.
 */

#include "Set.h"
#include "MemAlloc.h"
#include "SetP.h"

#include <assert.h>

#define CLASS_NAME "Set"
#include "CheckForDebris.h"

/* This function is only used in assert(). #ifndef to suppress gcc warnings. */
#ifndef NDEBUG
static Boolean CurrentIsOK( Set This )
{
    return This->Current >= 0 &&
           This->Current < SetNumberOfElements(This);
}
#endif

Set SetCreate(
    SetElementCompareFunction Compare,
    SetElementDestroyFunction Destroy )
{
    Set New = MemAlloc(  sizeof(struct _Set) );

    /* The elements are represented by an array of void * in a VarBuf. */
    New->Elements = VBCreate();

    New->Current = NO_CURRENT_ELEMENT;

    New->Compare = Compare;
    New->Destroy = Destroy;

    IncrementObjectCount();

    return New;
}


Natural SetNumberOfElements( Set This )
{
    return VBSize(This->Elements) / sizeof(void *);
}


void SetDestroy( Set This )
{
    if ( This != NULL )
    {
	int i;

	for ( i = 0; i < SetNumberOfElements(This); i++ )
	{
	    This->Destroy( ((void **)VBAddress(This->Elements))[i] );
	}
	VBDestroy( This->Elements );
	MemFree( This );

	DecrementObjectCount();
    }
}


void SetAddElement(
    Set This,
    void * Element )
{
    assert( This != NULL );

    SetFindElement( This, Element );
    if ( !SetElementExists( This ) )
    {

	VBAppendVoidPtr( This->Elements, Element );
    }

    This->Current = NO_CURRENT_ELEMENT;
}


/* Find an element using the compare function. */
void SetFindElement(
    Set This,
    void * Element )
{
    int i;

    assert( This != NULL );
    assert( Element != NULL );

    This->Current = NO_CURRENT_ELEMENT;

    /* This is currently implemented as a simple linear search. */
    for ( i = 0;
          This->Current == NO_CURRENT_ELEMENT && i < SetNumberOfElements(This);
	  i++ )
    {
	if ( !This->Compare( Element, 
	                     ((void **)VBAddress(This->Elements))[i] ) )
	{
	    This->Current = i;
	}
    }
}


Boolean SetElementExists( Set This )
{
    assert( This != NULL );
    return This->Current != NO_CURRENT_ELEMENT;
}


VarBuf SetGetElement( Set This )
{
    assert( This != NULL );
    assert( CurrentIsOK(This) );

    return ((void **)VBAddress(This->Elements))[This->Current];
}


Boolean SetForAllElements(
    Set This, 
    ForAllElementsCallback Callback, 
    void * ClientData )
{
    Boolean Success = True;
    int i;

    for ( i = 0; Success && i < SetNumberOfElements(This); i++ )
    {
	Success = Callback( ((void **)VBAddress(This->Elements))[i],
	                    ClientData );
    }

    return Success;
}
