/*
 * NAME
 *   StandardIO.h
 * COPYRIGHT
 *   Skim - Off-line news reading package optimized for slow lines.
 *   Copyright (C) 1996  Rene W.J. Pijlman
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * VERSION
 *   $Header: /home/rene/sys/CVS_MasterSourceRepository/skim/StandardIO.h,v 1.5 1996/02/16 23:10:54 rene Exp $
 *   Distributed with Skim version 0.8.4.
 */

#ifndef _STANDARD_IO_H_
#define _STANDARD_IO_H_

#include "VarBuf.h"
#include "Types.h"

typedef enum {
    OpenModeRead,                     /* File must exist. */
    OpenModeReadIgnore,               /* No error when file does not exist. */
    OpenModeWrite,                    /* File must not exist. */
    OpenModeWriteDiscardOld,          /* Overwrite file. */
    OpenModeAppend,                   /* Append to file. */
    OpenModeReadAndWriteDiscardOld
} OpenMode;


StandardIO SIOCreate( void );
void SIODestroy( StandardIO );

/* Symbolic values for the last parameter of the SIOFileOpen functions. */
#define FileMustExist       True

void SIOFileOpen( StandardIO, const char *, OpenMode);
void SIOFileOpenVB( StandardIO, VarBuf, OpenMode);
void SIOFileOpenFileDescriptorVB( StandardIO, int, VarBuf, OpenMode );

void SIOFileClose( StandardIO );

Boolean SIOIsOpenForWrite( StandardIO );
Boolean SIOIsOpenForRead( StandardIO );

void SIOPrintf( StandardIO, const char *, ... );

void SIOFlushBuffers( StandardIO );

Boolean SIOEndOfFile( StandardIO This );

void SIOFileGetPartOfLine( StandardIO, char *, int );

int SIORead( StandardIO, void *, int );
void SIOWrite( StandardIO, void *, int );

void SIOPrintError( const char * );

void SIOInternetCommand( StandardIO, const char * );

int SIOFileDescriptor( StandardIO );

Boolean SIOFileExists( const char * );
void SIORemove( const char * );

extern StandardIO StandardInput;
extern StandardIO StandardOutput;
extern StandardIO StandardError;

#endif /* _STANDARD_IO_H_ */
